@@ -6,6 +6,7 @@ use Data::Merger qw(merger);
 use Data::Walk;
 use Data::Dumper;
 use File::Path qw(make_path remove_tree);
+use Try::Tiny;
 
 with 'BioX::Workflow::Command::Utils::Files::TrackChanges';
 use BioX::Workflow::Command::Utils::Traits qw(ArrayRefOfStrs);
@@ -433,19 +434,22 @@ sub sanity_check_rule {
 
     my @keys = keys %{ $self->local_rule };
 
-    $self->app_log->info("");
-    $self->app_log->info("Beginning sanity check");
+    # $self->app_log->info("");
+    # $self->app_log->info("Beginning sanity check");
     if ( $#keys != 0 ) {
-        $self->app_log->fatal('You should only have one rule name!');
+        $self->app_log->fatal(
+            'Sanity check fail: There should be one rule name!');
         $self->sanity_check_fail;
         return;
     }
 
     $self->rule_name( $keys[0] );
-    $self->app_log->info( 'Sanity check on rule ' . $self->rule_name );
+
+    # $self->app_log->info( 'Sanity check on rule ' . $self->rule_name );
 
     if ( !exists $self->local_rule->{ $self->rule_name }->{process} ) {
-        $self->app_log->fatal('Your rule does not have a process!');
+        $self->app_log->fatal(
+            'Sanity check fail: Rule does not have a process!');
         $self->sanity_check_fail;
         return;
     }
@@ -458,7 +462,8 @@ sub sanity_check_rule {
 
         if ( !ref($ref) eq 'ARRAY' ) {
             $self->app_log->fatal(
-                'Your variable declarations should begin with an array!');
+'Sanity check fail: Your variable declarations should begin with an array!'
+            );
             $self->sanity_check_fail;
             return;
         }
@@ -537,7 +542,7 @@ Do the actual processing of the rule->process
 =cut
 
 sub template_process {
-    my $self = shift;
+    my $self  = shift;
     my $texts = [];
 
     #TODO we should not just spit this out as it compare_mtimes
@@ -550,7 +555,7 @@ sub template_process {
     ##TODO for modify chunks
     foreach my $sample ( $self->all_samples ) {
 
-      $texts = $self->check_chunks($sample, $texts);
+        $texts = $self->check_chunks( $sample, $texts );
     }
 
     $self->process_obj->{ $self->rule_name }->{text} = $texts;
@@ -595,9 +600,6 @@ sub in_template_process {
     my $sample = shift;
     my $texts  = shift;
 
-    $self->app_log->info(
-        'Processing Rule: ' . $self->rule_name . ' Sample: ' . $sample );
-
     $self->local_attr->sample($sample);
     $self->sample($sample);
     my $text = $self->eval_process();
@@ -654,8 +656,16 @@ sub walk_attr {
 
     $attr->walk_process_data( $self->rule_keys );
 
-    if ( $attr->create_outdir ) {
-        make_path( $attr->outdir );
+    if ( $attr->create_outdir && !$attr->outdir->is_dir ) {
+
+        try {
+            $attr->outdir->mkpath;
+        }
+        catch {
+            $self->app_log->fatal( "We were not able to make the directory.\n\t"
+                  . $attr->outdir
+                  . "\n\tError: $!" );
+        };
     }
 
     return $attr;
